# BeeKeeperRuntimeSDK
Described below is the EscrowAI Enclave API that provides functionality inside a BeeKeeperAI environment. Included are data engineering endpoints and reporting endpoints.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.5.1
- Package version: 1.0.0a
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import BeeEnclave
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import BeeEnclave
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import BeeEnclave
from BeeEnclave.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = BeeEnclave.Configuration(
    host = "https://localhost"
)



# Enter a context with an instance of the API client
with BeeEnclave.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = BeeEnclave.DataApi(api_client)
    filepath = 'filepath_example' # str | 

    try:
        # Retrieve a file by its filename
        api_response = api_instance.api_v1_data_file_get(filepath)
        print("The response of DataApi->api_v1_data_file_get:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DataApi->api_v1_data_file_get: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DataApi* | [**api_v1_data_file_get**](docs/DataApi.md#api_v1_data_file_get) | **GET** /api/v1/data/file | Retrieve a file by its filename
*DataApi* | [**api_v1_data_files_get**](docs/DataApi.md#api_v1_data_files_get) | **GET** /api/v1/data/files | Retrieve a list of available files
*DataApi* | [**api_v1_data_sql_select_post**](docs/DataApi.md#api_v1_data_sql_select_post) | **POST** /api/v1/data/sql/select | Execute a SQL query
*EscrowApi* | [**api_v1_ping_attestation_get**](docs/EscrowApi.md#api_v1_ping_attestation_get) | **GET** /api/v1/ping/attestation | Ping attestation authority
*EscrowApi* | [**api_v1_ping_enclave_get**](docs/EscrowApi.md#api_v1_ping_enclave_get) | **GET** /api/v1/ping/enclave | Ping to check if the enclave API is up
*EscrowApi* | [**api_v1_ping_escrow_get**](docs/EscrowApi.md#api_v1_ping_escrow_get) | **GET** /api/v1/ping/escrow | Ping to check if the backend Escrow service is up
*EscrowApi* | [**api_v1_ping_kms_get**](docs/EscrowApi.md#api_v1_ping_kms_get) | **GET** /api/v1/ping/kms | Ping key manager
*MlflowApi* | [**api20_mlflow_artifacts_artifact_path_delete**](docs/MlflowApi.md#api20_mlflow_artifacts_artifact_path_delete) | **DELETE** /api/2.0/mlflow-artifacts/{artifactPath} | Proxy DELETE request to MLflow Artifacts
*MlflowApi* | [**api20_mlflow_artifacts_artifact_path_get**](docs/MlflowApi.md#api20_mlflow_artifacts_artifact_path_get) | **GET** /api/2.0/mlflow-artifacts/{artifactPath} | Proxy GET request to MLflow Artifacts
*MlflowApi* | [**api20_mlflow_artifacts_artifact_path_post**](docs/MlflowApi.md#api20_mlflow_artifacts_artifact_path_post) | **POST** /api/2.0/mlflow-artifacts/{artifactPath} | Proxy POST request to MLflow Artifacts
*MlflowApi* | [**api20_mlflow_artifacts_artifact_path_put**](docs/MlflowApi.md#api20_mlflow_artifacts_artifact_path_put) | **PUT** /api/2.0/mlflow-artifacts/{artifactPath} | Proxy PUT request to MLflow Artifacts
*MlflowApi* | [**api20_mlflow_proxy_path_delete**](docs/MlflowApi.md#api20_mlflow_proxy_path_delete) | **DELETE** /api/2.0/mlflow/{proxyPath} | Proxy DELETE request to MLflow
*MlflowApi* | [**api20_mlflow_proxy_path_get**](docs/MlflowApi.md#api20_mlflow_proxy_path_get) | **GET** /api/2.0/mlflow/{proxyPath} | Proxy GET request to MLflow
*MlflowApi* | [**api20_mlflow_proxy_path_post**](docs/MlflowApi.md#api20_mlflow_proxy_path_post) | **POST** /api/2.0/mlflow/{proxyPath} | Proxy POST request to MLflow
*MlflowApi* | [**api20_mlflow_proxy_path_put**](docs/MlflowApi.md#api20_mlflow_proxy_path_put) | **PUT** /api/2.0/mlflow/{proxyPath} | Proxy PUT request to MLflow
*ReportApi* | [**api_v1_report_post**](docs/ReportApi.md#api_v1_report_post) | **POST** /api/v1/report | Post a valid report
*ReportApi* | [**api_v1_validate_post**](docs/ReportApi.md#api_v1_validate_post) | **POST** /api/v1/validate | Validate a report
*RunApi* | [**api_v1_algorithm_status_post**](docs/RunApi.md#api_v1_algorithm_status_post) | **POST** /api/v1/algorithm/status | Log the status of an algorithm execution


## Documentation For Models

 - [AlgorithmStatus](docs/AlgorithmStatus.md)
 - [ApiV1DataFilesGet200Response](docs/ApiV1DataFilesGet200Response.md)
 - [ApiV1ReportPost200Response](docs/ApiV1ReportPost200Response.md)
 - [File](docs/File.md)
 - [PingAttestationStatus](docs/PingAttestationStatus.md)
 - [PingEnclaveStatus](docs/PingEnclaveStatus.md)
 - [PingEscrowStatus](docs/PingEscrowStatus.md)
 - [PingKeyManagerStatus](docs/PingKeyManagerStatus.md)
 - [Report](docs/Report.md)
 - [SQLQuery](docs/SQLQuery.md)
 - [SQLResponse](docs/SQLResponse.md)
 - [ValidationResult](docs/ValidationResult.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author

engineering@beekeeperai.com


